import { AutoLoaderOptions } from './types_internal';
/**
 * It will register instrumentations and plugins
 * @param options
 * @return returns function to unload instrumentation and plugins that were
 *   registered
 */
export declare function registerInstrumentations(options: AutoLoaderOptions): () => void;
//# sourceMappingURL=autoLoader.d.ts.map